      PROGRAM     LIBMAIN
C
C
      IMPLICIT REAL*8 (A-H,O-Z)
C
C  A RELATIVISTIC SELF-CONSISTENT FIELD COMPUTER PROGRAM FOR ATOMS
C  AND IONS USING LOCAL POTENTIALS.
C
C  THE PROGRAM READS IN AN INITIAL CHARGE DENSITY AND OTHER ATOMIC DATA
C  (READIN), GENERATES A POTENTIAL FUNCTION (POT), AND SOLVES THE DIRAC
C  EQUATION FOR THE RADIAL WAVE FUNCTIONS (LIDEQ, START1, DIFF1,
C  START2,DIFF2). FROM THE NORMALIZED RADIAL WAVE FUNCTIONS A NEW CHARGE
C  DENSITY IS FORMED WHICH IS THEN AVERAGED WITH THE OLD ONE AND A NEW
C  POTENTIAL FUNCTION IS FORMED. THE WHOLE PROCEDURE IS REPEATED. AT
C  EACH STAGE THE NEW POTENTIAL FUNCTION IS COMPARED WITH THE OLD ONE
C  (POT) AND WHEN THESE MEET THE CONVERGENCE CRITERION THE ITERATION
C  IS STOPPED, VARIOUS ATOMIC DATA ARE PRINTED (OUTPUT).
C  A VARIETY OF POTENTIAL  FUNCTIONS MAY BE SPECIFIED.
C  ELECTRON BINDING ENERGIES MAY BE
C  COMPUTED IN DIFFERING WAYS.
C
C    RELATIVISTIC SELF-CONSISTENT FIELD PROGRAM FOR ATOMS AND IONS.
C    ===============================================
C        LIBERMAN, D.A., CROMER, D.T., WABER, J.T.
C        COMP. PHYS. COMMUN. 2 (1971) 107
C         A.M.BRATKOVSKY // MAY 1988 // AND FOR DOS 
C    ===============================================
C
C                 VARIABLES IN COMMON.
C
C  NAME       PROBLEM NAME.
C
C  N          NUMBER OF  POINTS IN RADIAL MESH.
C  J          NUMBER OF SHELLS.
C  RN         MAXIMUM RADIUS.
C  H          INTERVAL OF THE LOGARITHMIC MESH. READ AS THE RECIPROCAL.
C  Z, ZN      ATOMIC NUMBER.
C  XION       IONICITY.
C  PHI        AVERAGING FACTOR.
C  EPS        PARAMETER USED TO DETERMINE THE PRACTICAL INFINITY OF
C             EACH ORBITAL.
C  DEL        ACCURACY CRITERION FOR EIGENVALUES.
C  DELRVR     ACCURACY CRITERION FOR CONVERGENCE.
C
C  NC1        MAXIMUM NUMBER OF CYCLES BEFORE DUMP.
C_______________________________________________________________________
C     KPOT =
C               (-3)/' FREE-ELECTRON E-DEPENDENT VX '/
C               (-2)/' LIBERMAN EXCH.- TAIL CORRECTION'/
C  EXCHANGE-    (-1)/' SLATER RHO**1/3 '/     !! NOT USED
C CORRELATION   ( 0)/' GASPAR-KOHN-SHAM '/    !! NOT USED
C
C               ( 1)/' VON BARTH-HEDIN '       /
C               ( 2)/' GUNNARSON-LUDQUIST'     /
C               ( 3)/' JANAK-MORUZZI-WILLIAMS '/
C               ( 4)/' VOSKO-WILK-NUSAIR'      /
C                   /' PERDEW-ZUNGER'          /
C_______________________________________________________________________
C
C  XALPHA     SLATER EXCHANGE COEFFICIENT.
C  XLATTR     COULOMB TAIL PARAMETER.
C  FEX        CONTROL PARAMETER FOR FREE ELECTRON EXCHANGE POTENTIAL AND
C             BINDING ENERGY CALCULATIONS.
C  RNUC       RADIUS OF NUCLEUS IN BOHR RADII.
C
C  XN         RADIAL QUANTUM NUMBER.
C  XL         ORBITAL ANGULAR MOMENTUM OF MAJOR COMPONENT.
C  XJ         TOTAL ANGULAR MOMENTUM OF ORBITAL.
C  XE         EIGENVALUE.
C  XZ         NUMBER OF ELECTRONS IN SHELL.
C  BCOND      GIVES WIGNER-SEITZ BOUNDARY CONDITIONS IF SET TO 1.0.
C
C  RH         RADIAL CHARGE DENSITY.
C
C  FN,FL,FJ,E CURRENT VALUES OF XN, XL, XJ, XE.
C  VR: R*V(R) + Z  ---> WITHOUT COULOMB TERM (-->0 WHEN R->0), AT. UNITS !!!)
C  Q          INTEGRAL OF CHARGE DENSITY.
C  EV, ED     E-E POTENTIAL ENERGY  (HARTREE ELECTRON-ELECTRON TERM)
C  EV3, ER    INTEGRAL OF RHO(R)*V(R)
C  EV4,EZ     E-N POTENTIAL ENERGY  (ELECTRON IN NUCLEAR FIELD ENERGY).
C  EE2, EY    EXCHANGE ENERGY (EXCHANGE AND CORRELATION ENERGY).
C  V0         CONSTANT TERM IN POTENTIAL NEAR ORIGIN.
C  ET3        TOTAL ENERGY.
C  SUMMA      SUM OF EIGENVALUES.
C  PVT        TOTAL PRESSURE (LIBERMAN VIRIAL EXPRESSION FOR ATOM USED).
C  CONVRG     SET EQUAL TO 1.0 WHEN CONVERGENCE CRITERION IS MET.
C  PV         PRESSURE. TEMPORARY STORAGE.
C  A          MAJOR COMPONENT OF WAVE FUNCTION.  TEMPORARY STORAGE. !!!
C  B          MINOR COMPONENT OF WAVE FUNCTION.  TEMPORARY STORAGE. !!!
C  RHNLJ      TEMPORARY STORAGE.
C  DENS, Y    TEMPORARY STORAGE.
C  BINDEN     ELECTRON BINDING ENERGIES.
C  DA,DB      TEMPORARY STORAGE.
C  A0,B0      TEMPORARY STORAGE.
C  VRX        FREE ELECTRON EXCHANGE POTENTIAL CORRECTION. TEMPORARY
C             STORAGE (SHAM - KOHN E-DEPENDENT EXCHANGE)
C  XKOOP      SET TO +1.0 OR -1.0 WHEN COMPUTING BINDING ENERGIES.
C  R1         SPHERE RADIUS FOR "NEWPOT" - LIBERMAN POTENTIAL.
C  RAD        TABLE OF RADII.
C

        CHARACTER*60 NAME,FISTRT,DENFIL,OUTFIL,WFFILE,TABFIL
        CHARACTER*60 INFFILE
	INTEGER ACCU,ACCT
      COMMON /ACCESS/ ACCU,ACCT
      COMMON /FILE/ FISTRT,DENFIL,OUTFIL,WFFILE,TABFIL
      COMMON /LIBINF/INF,INFUN,INFFILE
      COMMON /CHAR/NAME
C
      COMMON /LIBGEN/RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
      COMMON /NP/RNK,ANK,BNK,NK
      COMMON /CORE/JCORE
C
      DIMENSION ERR(5)
      DIMENSION UR(421)
      DATA C/137.03602D0/
C
C  NT=TOTAL TIME IN MINUTES ALLOTTED FOR THIS RUN.
C
C     FILE  <INFFILE> FOR ADDITION INFORMATION ON CONVERGENCE
C     FILE  <WFFILE>  FOR WAVE FUNCTIONS
C     CALL ERRSET(208,0,1,0,0,0)
C
1     CONTINUE
C____________________________________________.
C    <READIN> READS THE INITIAL INFORMATION.
C____________________________________________.
      CALL READIN
C     """""""""""
      OPEN(4,FORM='UNFORMATTED',STATUS='UNKNOWN')
C     """""""""""""""""""""""""""""""""""""""""""
      CONVRG=0.5D0
      ET4=0.5D0
      ET3=0.0D0
C
      D=EXP(H)
      R=RN/D**N
         DO 2 K=1,N
         R=R*D
         RAD(K)=R
C
         A(K)=     0.0
         B(K)=     0.0
         DENS(K)=  0.0
         RHNLJ(K)= 0.0
         VR(K)=    0.0
         UR(K)=    0.0
         VRX(K)=   0.0
         Y(K)=     0.0
2     CONTINUE
C
C INITIAL DENSITY FROM ANALITYCAL APPROXIMATION (IN <START0> )
C
        CALL START0
C       ===========
      ERR(1)=1.0D20
      ERR(2)=ERR(1)
      ERR(3)=ERR(1)
      ERR(4)=ERR(1)
      ERR(5)=ERR(1)
      NCYCLE=NC1
      PH=2.0D0-PHI
C_______________________________________________________________
C  FILE 4 IS FOR TEMPORARY STORAGE OF THE RADIAL WAVE FUNCTIONS.
C  """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
      ITER=0
3     CONTINUE
C______________________________________
C  ATOM SELFCONCISTENCY LOOP BEGINS !!!
C______________________________________
      ITER=ITER+1
      WRITE(INFUN,1000)ITER
1000  FORMAT(/20(1H-),2X,'ITERATION',1X,I3,2X,40(1H-)/)
C     CALL TIMEL(TSTART)
      TSTART=0
      XKOOP=0.0D0
      ERR(1)=ERR(2)
      ERR(2)=ERR(3)
      ERR(3)=ERR(4)
      ERR(4)=ERR(5)
C
       CALL POT(RH,UR)
C      """""""""""""""
C____________________________________________________
C   CONTROL POINT FOR SELFCONSISTENCY
C   CONVRG = MAX(V_NEW(R) - V_OLD(R))  AFTER  < POT >
C____________________________________________________
      R1=RNK
      ERR(5)=CONVRG
      KCYCLE = NC1 - NCYCLE + 1
      IF((KCYCLE.LT.10).OR.(ERRM.NE.ERR(1)).OR.(PHI.LT.0.D0)) GOTO 8
      KEY = 0
         GOTO 18
8     CONTINUE
C-------------------------------------------------
C  ODINARY CONTINUATION OF THE CONVERGENCE PROCESS
C_________________________________________________
        DO 200 K = 1,N
200      VR(K) = UR(K)
C
      SUMMA=0.0D0
      PVT=0.0D0
      DO 9 K=1,N
9     DENS(K)=0.0D0
C
C-------------------------------------------------
C            ACCURACY CONTROL BLOCK
C-------------------------------------------------
      DELM=0.01D0
      IF (DABS(ET3-ET4).LT.0.1D0)
     *DELM=0.001D0
      IF (DABS(ET3-ET4).LT.0.001D0)
     *DELM=DEL
      DELL=DMIN1(DELM,DEL*DSQRT(CONVRG/DELRVR))
      IF (CONVRG.LT.DELRVR)
     *DELL=DEL
      IF(DELL.GT.DEL) DELL = DEL
C---------------------------------------------------------------------
C  THE USE OF A CONVERGENCE CRITERION, DELL, GREATER THAN DEL MAY LEAD
C  TO INSTABILITY. REPLACE IT WITH DELL=DEL IF NECESSARY.
C---------------------------------------------------------------------
C
           REWIND(4)
C
C        CYCLE FOR EACH ORBITAL IN ATOM 1(1)J  !!!
C        ------------------------------------
         DO 13 I=1,J
         BCOND=0.0D0
         IF (XN(I).LT.0.0D0)
     *   BCOND=1.0D0
         FN=DABS(XN(I))
         FL=XL(I)
         FJ=XJ(I)
         E=XE(I)
C
         IF (INT(FEX+.1).EQ.1)        CALL EXPOT
C------------------------------------------------------------
C  FOR FEX .EQ. 1 THE ROUTINE <EXPOT> IS CALLED AND ADDS THE
C  E-DEPENDENT XC-POTENTIAL. THE ROUTINE MAY BE REWRITTEN TO
C  ACCOMODATE OTHER E-DEPENDENT EXCHANGE SUCH AS MIGDALEK ONE
C  AND  SO  ON.  BELOW  THE  FULL ELECTRON DENSITY OF ATOM IS
C STORED IN ARRAY 'DENS' (SEE D0  12  ...).  THE  OTHER  WORK
C  ARRAY  ('RHNLJ')  MAY  BE  USED AS A STORAGE FOR ONLY CORE
C CHARGE DENSITY. THE NUMBER OF CORE LEVELS MUST BE SET UP IN
C INITIAL FILE (SEE FILES OF TYPE  RAT.* IN DIRECTORY "ADAT")
C AND IT IS STORED IN ARRAY /CORE/.  THE  ENERGY  OF  LEVELS,
C  COMPUTED  ON  PREVIOUS  STEP  ARE  STORED IN ARRAY 'XE(I)'
C  I=1(1)J
C------------------------------------------------------------
C        ==================
         CALL LIDEQ(DELL)
C        ==================
            DO 10 K=1,N
10          RHNLJ(K)=A(K)**2+B(K)**2
         SUMMA=SUMMA+XZ(I)*E
         IF (CONVRG.EQ.0.0D0)
     *   GOTO 11
C
         WRITE (4)(A(K),K=1,N)
         WRITE (4)(B(K),K=1,N)
C
         PV(I)=((A(N)**2+B(N)**2)*(E*RN+Z-VR(N)-VRX(N))+
     *   2.0D0*(C*B(N))**2*RN-(2.0D0*FJ+1.0D0)*C*A(N)*B(N))/3.0D0
         IF (XLATTR.EQ.0.0D0)
     *   PV(I)=PV(I)-0.0529456786D0*XALPHA*RHNLJ(N)*
     *   (RN*RH(N))**0.3333333333D0
         PVT=PVT+PV(I)*XZ(I)
11       XE(I)=E
            DO 12 K=1,N
12          DENS(K)=DENS(K)+XZ(I)*RHNLJ(K)
13       CONTINUE
C  ..................................................................
C  IF PHI IS NEGATIVE THE CHARGE DENSITY AVERAGING RATIO IS ABS(PHI).
C  IF PHI IS POSITIVE THE RATIO STARTS AT 1.0 AND DECREASES TO PHI.
      IF (PHI.GT.0.0D0)  GOTO 15
      PH=DABS(PHI)
      GOTO 16
15    PH=0.5D0*(PH+PHI)
16    PS=1.0D0-PH
      DO 17 K=1,N
17    RH(K)=PS*RH(K)+PH*DENS(K)
C  .................................................................
      ET4=ET3
      ET3=SUMMA-EV3+EV+EE2
      IF (RNUC.GT.0.0D0)
     *ET3=ET3+EV4
      WRITE (INFUN,23)Q,ET3,SUMMA,EV,EV3,EE2,RNK,ANK,BNK
C     CALL TIMEL(TFINISH)
      TFINISH=0.0
      CYCLET = TFINISH - TSTART
      WRITE (INFUN,20)CYCLET,PH
      IF(CONVRG.GT.DELRVR) GOTO 40
      KEY = 4
         GOTO 18
C----------------------------------- CONVERGENCE REACHED   ====> 18
40    CONTINUE
      NCYCLE = NCYCLE - 1
      IF(NCYCLE.NE.0) GOTO 3
C----------------------------------- TO THE NEXT ITERATION ====>  3
C
C        EXIT BLOCK WITH 'KEY'
C     ===========================
      KEY = 3
      WRITE(INFUN,1001)
1001  FORMAT(65(1H-)/
     *'   MAX. NUMBER OF ITERATIONS EXCEEDED IN SCF ATOM LOOP'/
     *65(1H-))
18       CONTINUE
      IF(KEY.NE.0) GOTO 30
      WRITE(INFUN,22)
      GOTO 31
30    CONTINUE
31    CONTINUE
C
C   <OUTPUT> TABULATES OUTPUT INFORMATION IN USUAL FORM
C   ===================================================
      IF(ACCT.EQ.1)     CALL OUTPUT
C                       """""""""""
C     <OUTDAT> WRITES INITIAL SCF DATA FOR LMTO
C     =========================================
      IF(ACCU.EQ.1)     CALL OUTDAT
C                       """""""""""
      CLOSE(UNIT=INFUN)
      CLOSE(UNIT=4,STATUS='DELETE')
      STOP
C
20    FORMAT(1X,'CYCLE TIME =',F6.2,' SECS.  CHARGE DENSITY ADMIXTURE ='
     *,1X,F10.7)
22    FORMAT(//' ERROR IN POTENTIAL IS NO LONGER DECREASING. ITERATION',
     *' TERMINATED ALTHOUGH CONVERGENCE CRITERION IS NOT MET.'//)
23    FORMAT(' TOT_CHARGE=',F10.5,' E_TOT=',F11.4,' SUM_EI=',F11.4,
     *' EL_EL=',F11.4 / ' EL_NUCL=',F11.4,' EXC=',F10.4,
     *  '// RNK=',F8.5,' ANK=',F5.1,' BNK=',F11.5)
      END
C***********************************************************************
      SUBROUTINE READIN
      IMPLICIT REAL*8 (A-H,O-Z)
C***********************************************************************
C  <READIN> READS INPUT DATA DECKS .
C  NOMINAL
C  VALUES OF SOME OF THE INPUT DATA WILL BE SUPPLIED IF BLANK SPACES
C  ARE LEFT ON THE  CARDS. VARIOUS TESTS ARE APPLIED TO SEE IF THE INPUT
C  DATA ARE CONSISTENT AND WHEN THEY ARE NOT A SKIP TO THE NEXT DATA
C  DECK IS ATTEMPTED. CALLED BY < HEX >.
C***********************************************************************
        CHARACTER*60 NAME,FISTRT,DENFIL,OUTFIL,WFFILE,TABFIL
        CHARACTER*60 INFFILE,TXTORB(35)*6
        INTEGER ACCU,ACCT
      COMMON /FILE/ FISTRT,DENFIL,OUTFIL,WFFILE,TABFIL
      COMMON /LIBGEN/RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
C
	DIMENSION EINIT(36)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
      COMMON /ACCESS/ ACCU,ACCT
      COMMON /LIBINF/INF,INFUN,INFFILE
C
      COMMON /CHAR/NAME
      COMMON /CORE/JCORE
C
1     CONTINUE
C
C--------------------------------------------------------
C	INPUT FILE FOR ATOMIC CALCULATIONS
C--------------------------------------------------------
	PRINT*,'ENTER  RAT.?  FILE NAME FOR ? ELEMENT'
	READ(5,1000)FISTRT
1000	FORMAT(A60)
        OPEN(1,FILE= FISTRT,STATUS = 'OLD',FORM='FORMATTED')
C
        READ (1,60) NAME
60      FORMAT(A60/)
	READ(1,*)ACCU,OUTFIL
	READ(1,*)ACCT,TABFIL
	READ(1,*)INF,INFFILE
	READ(1,*)J,JCORE
	READ(1,*)ZN,XION,XLATTR
	READ(1,*)PHI,ITERMAX
	READ(1,*)DEL,DELRVR
	NC1 = ITERMAX
      IF ((J.LE.0).OR.(ZN.LE.0.0D0))
     %   STOP 'ORBITALS OR NUCL.CHARGE UNDEFINED'
	IF(INF.EQ.6) THEN
	INFUN=6
	ELSE
	INFUN=2
      OPEN(UNIT=INFUN,FILE=INFFILE,STATUS='UNKNOWN',FORM='FORMATTED')
	ENDIF
C
C    *************** STANDARD INITIAL VALUES *************
C    *   N=421
C    *   RN=60.
C    *   H1=32.
C    *   PHI=0.3
C    *   EPS=75.
C    *   DEL=0.000005
C    *   DELRVR=0.0001
C    *****************************************************
	N    = 421
	RN   = 60.
	H1   = 32.0
	EPS  = 75.0
	BCOND = 0.
        IF (NC1.EQ.0)          NC1=30
	READ(1,*) KPOT
	READ(1,*) FEX
	READ(1,*) ANUC
	RNUC =    ANUC
      H=1.0D0/H1
      Z=ZN
C    *****************************************************
C		FOR NON-POINT NUCLEUS
C		"""""""""""""""""""""
      IF (RNUC.EQ.0.0D0)      GOTO 3
C  .....................................................................
C  IF RNUC IS SET TO A VALUE GREATER THAN 1.0 IT IS ASSUMED THAT THIS IS
C  THE NUCLEAR MASS NUMBER, A, AND THE NUCLEAR RADIUS IS COMPUTED FROM
C  THE FORMULA R=1.1*A**(1/3) FERMIS.
C  .....................................................................
      IF (RNUC.GE.1.0D0)     RNUC=0.0000208D0*RNUC**(1.0D0/3.0D0)
      Z=0.0D0
      R=RN*DEXP(-(N-3)*H)
      IF (RNUC.GT.R)     GOTO 3
C
      WRITE (INFUN,22)
C
3     IF (KPOT.EQ.-2) THEN
        XALPHA=2.0D0/3.0D0
        XLATTR=1.0D0
      ENDIF
	READ(1,*)FINITE		
	INITE = INT(FINITE+.1)
C**************************************************************
C	INITE = 1 : READ OF INITIAL ENERGY LEVELS
C	(DATA IN RY UNITS !!!)
C**************************************************************
C   ***********************************
C   READ DATA ON ELECTRON CONFIGURATION
C   """""""""""""""""""""""""""""""""""
	READ(1,1001)TXT
1001	FORMAT(/A60)
		IF (INITE.EQ.1) THEN
	DO 150 I=1,J
C	READ(1,FMT=1130,ERR=160)TXTORB(I),XN(I),XL(I),XJ(I),XZ(I),EINIT(I)
C160	BACKSPACE(1)
	READ(1,FMT=1129)TXTORB(I),XN(I),XL(I),XJ(I),XZ(I),EINIT(I)
150	CONTINUE
C
1129    FORMAT(5X,A6,2X,3F5.1,F10.1,1PE19.7)
1130    FORMAT(4X,A6,2X,3F5.1,F10.1,1PE19.7)
C
	DO 50 I=1,J
50	XE(I) = .5 * EINIT(I)
		ELSE
	DO 151 I=1,J
	READ(1,FMT=1130,ERR=170)TXTORB(I),XN(I),XL(I),XJ(I),XZ(I)
170	BACKSPACE(1)
	READ(1,FMT=1129)TXTORB(I),XN(I),XL(I),XJ(I),XZ(I)
151	CONTINUE
		ENDIF
C****************TEST BLOCK********************************
C      WRITE(INFUN,*)(XN(I),I=1,J)
C      WRITE(INFUN,*)(XL(I),I=1,J)
C      WRITE(INFUN,*)(XJ(I),I=1,J)
C      WRITE(INFUN,*)(XZ(I),I=1,J)
C----------------------------------------------------------
      SUM=0.0D0
      DO 7 I=1,J
	IF(INITE.NE.1) THEN
C  -----------------------------------------
C  INITIAL ENERGIES FROM TRIVIAL SCREENING
C  -----------------------------------------
	ZSHELL = 0.
	IF(I.GT.1) THEN
	    DO 40 K=1,INT(XN(I-1)+.1)
40	    ZSHELL = ZSHELL + XZ(K)	
	ENDIF
	XE(I) = -0.5*((Z-ZSHELL)/XN(I))**2
C       """"""""""""""""""""""""""""""""""
	ENDIF
C  --------------------------------
C  ****** CHECK INITIAL DATA ******
C  --------------------------------
      SUM=SUM+XZ(I)
      IF ((XN(I)-XL(I)-1.0D0).LT.0.0D0)     GOTO 8
      IF (ABS(ABS( XL(I) - XJ(I) )- 0.5D0 ).GE. 0.001 )     GOTO 8
      IF ((2.0D0*XJ(I)+1.0D0).LT.XZ(I))     GOTO 8
C     IF (BCOND.EQ.1.0D0)    XN(I)=-XN(I)
7     CONTINUE
      IF (ABS(SUM+XION-ZN).GT.0.000001D0)    GOTO 9
      GOTO 10
8     WRITE (INFUN,60)NAME
      WRITE (INFUN,17)I,XN(I),XL(I),XJ(I),XZ(I)
	STOP 'ERROR IN INPUT DATA'
      GOTO 10
9     WRITE (INFUN,60)NAME
      STOP ' TOTAL NUMBER OF ELECTRONS IN ERROR '
10    CONTINUE
	CLOSE(1)
C
C     READ INITIAL CHARGE DISTRIBUTION
C     """"""""""""""""""""""""""""""""
C      IF (NREAD.NE.0)    WRITE (INFUN,101)
C___________________________________________________________
C     G OF INITIAL ATOMIC DENSITY
C	BLOCK FOR READING IMPROVED INITIAL DENSITY
C__________________________________________________________
C        IF (NREAD.NE.0)   THEN
C        OPEN(3,FILE=DENFIL)
C         READ (3,*) (RH(I),I=1,N)
C        CLOSE(3)
C      ENDIF
      RETURN
C
15    FORMAT(' XALPHA NOT SPECIFIED. XALPHA MADE 1.0')
16    FORMAT(3F5.1,F14.7,F7.4,20X,F4.0)
17    FORMAT(' ERROR ON ORBITAL ',I3,' N=',F5.2,' L=',F5.2,
     1        ' J=',F5.2,' Z=',F5.2)
18    FORMAT(1H , A80)
20    FORMAT(5E14.7)
21    FORMAT(1P8E15.7)
22    FORMAT(' LESS THAN THREE MESH POINTS INSIDE NUCLEUS.')
101   FORMAT(' INITIAL RHO(R) DATA  USED')
      END
C*******************************************************************
C                    <LIBDIR>
C
C  PACK FOR COMPUTING SCF-POTENTIAL FROM ATOMIC ORBITALS,
C     BINDING ENERGIES AND PREPAIRING EXTENDED OUTPUT
C     LIBERMAN,CROMER,WABER
C     A.M.BRATKOVSKY REVISION 1989 FOR MS DOS FORTRAN
C*******************************************************************
      SUBROUTINE START0
      IMPLICIT REAL*8 (A-H,O-Z)
C*******************************************************************
C     COMPUTES AN INITIAL RADIAL CHARGE DISTRIBUTION
C     (INTERPOLATION OF THOMAS-FERMI TYPE)
C*******************************************************************
       CHARACTER NAME*60
       CHARACTER*60 INFFILE
C
      COMMON /CHAR/NAME
      COMMON /LIBGEN/RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
      COMMON /LIBINF/INF,INFUN,INFFILE
C
      ALPHA=0.3058D0*(ZN-XION)**(1.0D0/3.0D0)
      BETA=5.8632D0*DMAX1(0.0D0,ZN-XION-2.0D0)*ALPHA
      GAMMA=(4.0D0+3.2D0*XION)
      G2=GAMMA**3
      IF ((ZN-XION).LT.2.0D0)
     *G2=0.5D0*(ZN-XION)*G2
      DO 1 K=1,N
      R=RAD(K)
      X=ALPHA*R
1     RH(K)=BETA*DSQRT(X)*DEXP(-3.0D0*X)+G2*R**2*DEXP(-GAMMA*R)
C
C      IF (NDEBUG.NE.1)     WRITE (INFUN,2)(RH(I),I=1,N)
C
      RETURN
C
2     FORMAT(8E15.7)
      END
C----------------------------------------------------------------------
      SUBROUTINE POT(RHO,UR)
      IMPLICIT REAL*8 (A-H,O-Z)
C**********************************************************************
C  POT COMPUTES THE SELF-CONSISTENT FIELD POTENTIAL FUNCTION FROM THE
C  CHARGE DENSITY AND SEVERAL TOTAL ENERGIES. AS THE POTENTIAL FUNCTION
C  IS COMPUTED IT IS COMPARED WITH THE OLD ONE AND CONVRG IS SET EQUAL
C  TO THE MAXIMUM DIFFERENCE BETWEEN THE TWO. POT IS ALSO USED IN THE
C  COMPUTATION OF ELECTRON BINDING ENERGIES BY < BIND >.
C**********************************************************************
       CHARACTER*60 NAME
       CHARACTER*60 INFFILE
       COMMON /LIBINF/INF,INFUN,INFFILE

      COMMON /CHAR/NAME
      COMMON /LIBGEN/RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
      COMMON /NP/RNK,ANK,BNK,NK
      DIMENSION RHO(421),UR(421),C(421),DC(5)
      EQUIVALENCE (DC(1),A0(1)),(C(1),RHNLJ(1))
      DATA PI/3.141592654D0/
C
      QBRT4(X)=X**0.333333333333D0
C
C_______________________________________________________________________
C     KPOT =    (-3)/' FREE-ELECTRON E-DEPENDENT VX '/
C               (-2)/' LIBERMAN EXCH.- TAIL CORRECTION'/
C               (-1)/' SLATER RHO**1/3 '/
C               ( 0)/' GASPAR-KOHN-SHAM '/
C
C               ( 1)/' VON BARTH-HEDIN '/
C               ( 2)/' GUNNARSSON-LUDQUIST'/
C               ( 3)/' JANAK-MORUZZI-WILLIAMS '/
C               ( 4)/' VOSKO-WILK-NUSAIR'/
C                   /' PERDEW-ZUNGER'/
C_______________________________________________________________________
      CONST=1.5D0/PI*QBRT4(0.75D0*PI)
      CONSTT=CONST*XALPHA
      S2=2.0D0
      IF (RH(1).NE.0.0D0.AND.RH(2).NE.0.0D0)
     *S2=DLOG(RH(2)/RH(1))/H
      Z=ZN
      IF (RNUC.EQ.0.0D0)
     *ZN=0.0D0
      NK=0
      RNK=RN
      ANK=Z-XLATTR-XION-XKOOP
      RU=ANK
      IF (RU.LT.0.0D0)
     *RU=0.0D0
      S3=S2+1.0D0
      ENUC=0.0D0
      IF (RNUC.GT.0.0D0)
     *RU=RU-ZN
      H3=H/3.0D0
      R=RAD(1)
      A(1)=RHO(1)*R/S3
      B(1)=RHO(1)/S2
      DB(1)=H3*RHO(1)
      DA(1)=DB(1)*R
      S5=S2+3.0D0
      C(1)=RHO(1)*R**3/S5
      DC(1)=DA(1)*R**2
      R=RAD(2)
      A(2)=RHO(2)*R/S3
      B(2)=RHO(2)/S2
      DB(2)=H3*RHO(2)
      DA(2)=DB(2)*R
      NC=0
      C(2)=RHO(2)*R**3/S5
      DC(2)=DA(2)*R**2
      DO 1 K=3,N
      R=RAD(K)
      DB(3)=H3*RHO(K)
      DA(3)=DB(3)*R
      DC(3)=DA(3)*R**2
      A(K)=A(K-2)+DA(3)+4.0D0*DA(2)+DA(1)
      B(K)=B(K-2)+DB(3)+4.0D0*DB(2)+DB(1)
      C(K)=C(K-2)+DC(3)+4.0D0*DC(2)+DC(1)
      IF (A(K).LT.ANK)
     *NK=K
      IF (R.LE.RNUC)
     *NC=K
      DA(1)=DA(2)
      DB(1)=DB(2)
      DA(2)=DA(3)
      DC(1)=DC(2)
      DC(2)=DC(3)
1     DB(2)=DB(3)
      NC=NC+1
      NK=MIN0(NK+1,N)
      QA=A(N)
      ZB=-Z*B(N)
      EZ=0.0D0
      IF (RNUC.EQ.0.0D0)
     *GOTO 2
      ANC=CUBINT(RNUC,NC,RAD,A,N)
      BNC=CUBINT(RNUC,NC,RAD,B,N)
      CNC=CUBINT(RNUC,NC,RAD,C,N)
      EZ=ZB-Z*(1.5D0*ANC/RNUC-BNC-0.5D0*CNC/RNUC**3)
      ZB=EZ
2     IF (KPOT.NE.-2)   GOTO 4
      RNK=0.0D0
      BNK=0.0D0
      DX=0.0D0
      IF (NK.LT.3)
     *GOTO 5
      RNK=CUBINT(ANK,NK,A,RAD,N)
      BNK=CUBINT(ANK,NK,A,B,N)
      DX=DLOG(RAD(NK)/RNK)
      GOTO 5
4     NK=N
      RNK=RN
      BNK=B(N)
      DX=0.0D0
C__________________________________________
C     RHO  = 4*PI*R^2 * ROEL = A**2 + B**2
C     ROEL = THE TRUE ELECTRON DENSITY !!!
C     THE CYCLE OF Y(K)=VXCH  STARTS
C__________________________________________
5     CONTINUE
      DO 6 K=1,N
      R=RAD(K)
      RDEN=RHO(K)
C------------------------------> BELOW : EXCH-CORR. POTENTIAL
      IF(KPOT.GE.1) THEN
         ROEL = RDEN/(4.*PI*R*R)
         VXCH =  0.5* VXC(ROEL/2.,ROEL/2.,KPOT,1)*R
         Y(K) = VXCH
      ELSE
         YYYY = -CONSTT*QBRT4(RDEN*R)
         Y(K) =  YYYY
      ENDIF
C________________________________
6     CONTINUE
      VNK=0.0D0
      IF ((NK.GT.2).AND.(NK.LT.N))
     *VNK=0.75D0*CUBINT(ANK,NK,A,Y,N)/RNK
      V0=BNK-VNK+Y(1)/RAD(1)-1.5D0*ZN/(RNUC+1.0D-40)
      BN=B(N)
      R0=0.0D0
      EPSLON=0.0D0
C_____________________ CYCLE 17 STARTED: PREPAIRING FOR INTEGRATION
      DO 17 K=1,N
      R=RAD(K)
      IF (R.GT.RNUC)    GOTO 8
      X=R/RNUC
      RVN=-Z*X*(1.5D0-0.5D0*X**2)
        GOTO 9
8     RVN=-ZN
9     IF (KPOT.EQ.-3)   GOTO 10
        GOTO 11
10    IF (K.LT.NK)      GOTO 12
        GOTO 13
11    IF (R0.LE.0.0D0)  GOTO 12
        GOTO 13
C_______________________________________________________
12    RV = A(K) + R*(BNK-B(K)-VNK) + Y(K) + RVN
C_______________________________________________________
C     RV = R*VFULL + ZN = POTENTIAL WITHOUT COULOMB TERM
C     """"""""""""""""""""""""""""""""""""""""""""""""""
        GOTO 14
13    RV=RU
14    IF (RV.GE.RU)
     *R0=1.0D0
      IF (XKOOP.NE.0.0D0) GOTO 16
      ERROR=DABS(RV-UR(K))/R
      IF (ERROR.LT.EPSLON)
     *GOTO 16
      EPSLON=ERROR
      NERROR=K
16    UR(K)=RV
        RDEN = RHO(K)
        ROEL = RDEN/(4.*PI*R*R)
        RHNLJ(K)=RDEN*VR(K)
      IF(KPOT.GE.-1) THEN
        EXCH =  R*RDEN* 0.5 * EXC(ROEL/2.,ROEL/2.,KPOT)
        Y(K) = EXCH
      ELSE
        YYYY = - 0.5D0*CONST*QBRT4(RDEN*R)*RDEN
        Y(K) = YYYY
      ENDIF
        A(K)=A(K)*RDEN
17    CONTINUE
C________________________  CYCLE 17 FINISHED
      ZN=Z
      IF (RNUC.GT.0.0D0)
     *Z=0.0D0
C____________________________________________________
C     CALCULATION OF THE DF-ENERGIES:
C     EY = EXCHANGE-CORRELATION
C     ED = HARTREE ELECTRON-ELECTRON
C     ER = ELECTRON IN EXTERNAL SELF-CONSISTENT FIELD
C____________________________________________________
      EY=0.0D0
      ED=0.0D0
      ER=0.0D0
      IF (NK.LT.10)
     *GOTO 19
      EY=ADLINT(Y,NK,H)+Y(1)/3.0D0
      ED=ADLINT(A,NK,H)+A(1)/5.0D0
      ER=ADLINT(RHNLJ,NK,H)+RHNLJ(1)/3.0D0
      IF (NK.GE.N-1)
     *GOTO 19
      EY=EY-ENDCOR(Y,DX,NK,H)
      ED=ED-ENDCOR(A,DX,NK,H)+ANK*(BN-BNK)
      ER=ER-ENDCOR(RHNLJ,DX,NK,H)+(ANK+XKOOP-ZN+Z)*(BN-BNK)
19    IF (XKOOP.NE.0.0D0)
     *RETURN
      EE2=EY
      EV=ED
      EV3=ER
      Q=QA
      EV4=ZB
      CONVRG=DABS(EPSLON)
C
      WRITE (INFUN,20)EPSLON,NERROR
C
      RETURN
C
20    FORMAT('MAX. ERROR IN V(R) IS ',E14.7,' AT THE ',I4,'TH POINT')
      END
      FUNCTION ENDCOR (Y,DX,N,H)
      IMPLICIT REAL*8 (A-H,O-Z)
C  -----------------------------------------
C  QUADRATIC END CORRECTION FOR INTEGRATION.
C  CALLED BY <POT>.
C  -----------------------------------------
      DIMENSION Y(421)
C
      D=DX/H
      ENDCOR=DX*(Y(N)-0.25D0*(Y(N+1)-Y(N-1))*D+0.16666667D0*(Y(N+1)-2.0D
     *0*Y(N)+Y(N-1))*D*D)
      RETURN
      END
      FUNCTION CUBINT (XJ,N,X,Y,NX)
      IMPLICIT REAL*8 (A-H,O-Z)
C  --------------------------------------------------------------------
C  CUBIC LAGRANGE INTERPOLATION TO FIND Y(XI). N IS A LOCATION IN THE
C  TABLE OF X NEAR XI. USUALLY XI IS BETWEEN X(N-1) AND X(N).
C  CALLED BY <POT>.
C  --------------------------------------------------------------------
	CHARACTER*60 INFFILE
	COMMON /LIBINF/INF,INFUN,INFFILE
      DIMENSION X(NX),Y(NX)
C
      IF (N.GE.NX)
     *GOTO 1
      XI=XJ
      AMM=(XI-X(N-1))*(XI-X(N))*(XI-X(N+1))
      AM=(XI-X(N-2))*(XI-X(N))*(XI-X(N+1))
      A=(XI-X(N-2))*(XI-X(N-1))*(XI-X(N+1))
      AP=(XI-X(N-2))*(XI-X(N-1))*(XI-X(N))
      XI=X(N-2)
      BMM=(XI-X(N-1))*(XI-X(N))*(XI-X(N+1))
      XI=X(N-1)
      IF (BMM.EQ.0.0D0)
     *GOTO 1
      BM=(XI-X(N-2))*(XI-X(N))*(XI-X(N+1))
      XI=X(N)
      IF (BM.EQ.0.0D0)
     *GOTO 1
      B=(XI-X(N-2))*(XI-X(N-1))*(XI-X(N+1))
      XI=X(N+1)
      IF (B.EQ.0.0D0)
     *GOTO 1
      BP=(XI-X(N-2))*(XI-X(N-1))*(XI-X(N))
      IF (BP.EQ.0.0D0)
     *GOTO 1
      CUBINT=Y(N-2)*AMM/BMM+Y(N-1)*AM/BM+Y(N)*A/B+Y(N+1)*AP/BP
      RETURN
1     CUBINT=Y(NX)
      WRITE (INFUN,2)N,X(N-2),X(N-1),X(N),X(N+1)
      RETURN
C
2     FORMAT(' TROUBLE IN CUBINT. SET EQUAL TO Y(N).',I5,4E14.7)
      END
C------------------------------------------------------------------
      SUBROUTINE BIND
      IMPLICIT REAL*8 (A-H,O-Z)
C******************************************************************
C  CALCULATES APPROXIMATE ELECTRON BINDING ENERGIES.
C  CALLED BY <LIBMAIN>
C******************************************************************
       CHARACTER*60 NAME,FRM*12
       LOGICAL OPN
      COMMON /CHAR/NAME
      COMMON /LIBGEN/RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
      DATA CC/0.4235654286D0/
C
C      DATA TEXCH(-3)/' FREE-ELECTRON E-DEPENDENT VX '/
C      DATA TEXCH(-2)/' LIBERMAN EXCH.- TAIL CORRECTION'/
C      DATA TEXCH(-1)/' SLATER RHO**1/3 '/
C      DATA TEXCH( 0)/' GASPAR-KOHN-SHAM '/
C      DATA TEXCH( 1)/' VON BARTH-HEDIN '/
C      DATA TEXCH( 2)/' GUNNARSSON-LUNDQUIST'/
C      DATA TEXCH( 3)/' JANAK-MORUZZI-WILLIAMS '/
C      DATA TEXCH( 4)/' VOSKO-WILK-NUSAIR'/
C
      QBRT4(X)=X**0.333333333333D0
C
	KFEX = INT(FEX+.1)
      IF (KFEX.EQ.2)     GOTO 1
      IF (KFEX.EQ.3)     GOTO 9
      IF (KPOT.GE.-1)     GOTO 4
      IF (KPOT.EQ.-2)     GOTO 9
      RETURN
C_______________________________________________________________
C  APPROXIMATE HARTREE-FOCK BINDING ENERGIES.
C_______________________________________________________________
1     DO 3 I=1,J
      BINDEN(I)=XE(I)
      DO 2 K=1,10
      BCOND=0.0D0
C     IF (XN(I).LT.0.0D0)     BCOND=1.0D0
      FN=DABS(XN(I))
      FL=XL(I)
      FJ=XJ(I)
      E=BINDEN(I)
      CALL EXPOT
      CALL LIDEQ(DEL)
      IF (DABS(BINDEN(I)-E).LT.0.0005D0)
     *GOTO 3
2     BINDEN(I)=E
3     BINDEN(I)=E
      RETURN
C_____________________________________________________
C  BINDING ENERGY CORRECTION TO KOHN-SHAM EIGENVALUES.
C_____________________________________________________
4     H3=H/3.0D0
C
      REWIND(UNIT=4)
C      INQUIRE(UNIT=4,OPENED=OPN,FORM=FRM)
C      WRITE(6,*)' OPN=',OPN,' FRM=',FRM
C      WRITE(6,*)' J=',J,'N=',N
C_________________CYCLE OVER ALL ORBITALS STARTED
      DO 8 I=1,J
        READ (4,ERR=800,END=900)(B(M),M=1,N)
        READ (4,ERR=800,END=900)(A(M),M=1,N)
        FN=DABS(XN(I))
        FL=XL(I)
        FJ=XJ(I)
        E=XE(I)
        R=RAD(1)
        B(1)=A(1)**2+B(1)**2
        DA(1)=H3*B(1)*R
        A(1)=B(1)*R/3.0D0
        R=RAD(2)
        B(2)=A(2)**2+B(2)**2
        DA(2)=H3*B(2)*R
        A(2)=B(2)*R/3.0D0
          DO 5 K=3,N
          B(K)=A(K)**2+B(K)**2
          R=RAD(K)
          DA(3)=H3*B(K)*R
          A(K)=A(K-2)+DA(3)+4.0D0*DA(2)+DA(1)
          DA(1)=DA(2)
          DA(2)=DA(3)
5         CONTINUE
      DO 6 K=1,N
6     A(K)=B(K)*A(K)
      VI=-ADLINT(A,N,H)-A(1)/5.0D0
C____________________________________INTEGRAL ON VXCH
        DO 7 K=1,N
        R=RAD(K)
        QF=QBRT4(RH(K)*R)
        QFP=QBRT4((RH(K)+B(K))*R)
        Y(K)=B(K)*QF-0.75D0*RH(K)*(QFP-QF)-0.75D0*B(K)*QFP
        IF (XZ(I).LT.1.0D0)  GOTO 7
        QFM=RH(K)-B(K)
        IF (QFM.LT.0.0D0)    QFM=0.0D0
        QFM=QBRT4(QFM*R)
        A(K)=B(K)*QF-0.75D0*RH(K)*(QF-QFM)-0.75D0*B(K)*QFM
7       CONTINUE
C_______________________________________________________
      XI=0.0D0
      YI=0.0D0
      IF (XZ(I).GE.1.0D0)
     *XI=(ADLINT(A,N,H)+A(1)/3.0D0)*CC
      IF (XZ(I).LE.2.0D0*XJ(I))
     *YI=(ADLINT(Y,N,H)+Y(1)/3.0D0)*CC
      BINDEN(I)=E+VI+XI
      PV(I)=-E+VI-YI
8     CONTINUE
C_________________CYCLE OVER ALL ORBITALS ENDED
      RETURN
800   STOP '<BIND>: ERROR READING UNIT 4'
900   STOP '<BIND>: END OF FILE UNIT 4'
C___________________________________________________________
C  BINDING ENERGIES FROM DIFFERENCES OF TOTAL ENERGIES.
C___________________________________________________________
9     REWIND (UNIT=4)
C
      DO 14 I=1,J
      READ (4)(B(M),M=1,N)
      READ (4)(A(M),M=1,N)
      DO 10 K=1,N
      B(K)=A(K)**2+B(K)**2
      VRX(K)=RH(K)+B(K)
      DENS(K)=RH(K)-B(K)
      IF (DENS(K).LT.0.0D0)
     *DENS(K)=0.0D0
10    CONTINUE
      IF (XZ(I).LT.1.0D0)
     *GOTO 12
      XKOOP=1.0D0
      CALL POT(DENS,B)
      SUMMB=SUMMA-XE(I)
      ET4=SUMMB-ER+ED+EY+EZ
      BINDEN(I)=ET3-ET4
12    IF (XZ(I).GT.2.0D0*XJ(I))
     *GOTO 14
      XKOOP=-1.0D0
      CALL POT(VRX,B)
      SUMMB=SUMMA+XE(I)
      ET4=SUMMB-ER+ED+EY+EZ
      PV(I)=ET3-ET4
14    CONTINUE
      RETURN
      END
C-----------------------------------------------------------------------
      SUBROUTINE EXPOT
      IMPLICIT REAL*8 (A-H,O-Z)
C***********************************************************************
C  LOCAL ELECTRON EXCHANGE POTENTIAL. USED IN THE
C  SELF-CONSISTENT FIELD CALCULATION IF FEX=1 AND IN THE COMPUTATION
C  OF ELECTRON BINDING ENERGIES IF FEX=2.0.
C  CALLED BY <HEX> AND <BIND>.
C***********************************************************************
       CHARACTER*60 NAME

      COMMON /CHAR/NAME
      COMMON /LIBGEN/RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
C_____________________________________________________________
C  P1=1/PI,  P3=3*PI**2,  P4=1/(4*PI)
C_____________________________________________________________
      DATA PI,P1,P3,P4/3.14159265D0,0.318309886D0,29.6088131D0,0.0795774
     *71D0/
      QBRT4(X)=X**0.333333333333D0
      DO 90 K=1,N
      R=RAD(K)
C
C  LOCAL FERMI MOMENTUM  'QF'
C
      RHO=RH(K)*P4/R/R
      QF=QBRT4(P3*RHO)
C     IF(KPOT.EQ.-2) THEN
       VXMIN=-P1*QF*R
       VXMAX=-VXMIN*1.5D0*XALPHA
       VXMIN=2.0D0*VXMIN+VXMAX
       VRX(K)=0.5D0*(VXMIN+VXMAX)
        DO 8 L=1,10
        IF (QF.LT.0.000001D0)    GOTO 4
        T=E-(VR(K)+VRX(K)-Z)/R
        IF (T.LT.0.0D0)   GOTO 1
        ETA=DSQRT(T+T)/QF
        IF (ETA.LT.0.01D0) GOTO 2
        IF (DABS(ETA-1.0D0).LT.0.000001D0)  GOTO 3
        AL=LOG( ABS(1.0+ETA)/(ABS(1.0-ETA)+1.D-20) )
        XR=1.0D0+0.5D0*(1.0D0/ETA-ETA)*AL
        XRP=(1.0D0-0.5D0*(1.0D0/ETA+ETA)*AL)/ETA
        GP=1.0D0-P1*XRP/ETA/QF
        IF (GP.GT.4.0D0) GP=4.0D0
        GOTO 5
1       XR=2.0D0
        GP=1.0D0
        GOTO 5
2       XR=2.0D0-0.666666667D0*ETA*ETA
        GP=1.0D0+1.333333333D0*P1/QF
        IF (GP.GT.4.0D0)   GP=4.0D0
        GOTO 5
3       XR=1.0D0
        GP=1.0D0+15.0D0*P1/QF
        IF (GP.GT.4.0D0)  GP=4.0D0
        GOTO 5
4       XR=0.0D0
        GP=1.0D0
5       VX=-P1*R*QF*(XR-1.5D0*XALPHA)
        VX=(VX+(GP-1.0D0)*VRX(K))/GP
        IF (ABS(VX-VRX(K))/(ABS(VX)+1.D-10).LT.0.001D0)  GOTO 9
        IF (VX-VRX(K))6,9,7
6       VXMAX=VRX(K)
        IF (VX.LT.VXMIN)   VX=0.5D0*(VXMAX+VXMIN)
        GOTO 8
7       VXMIN=VRX(K)
        IF (VX.GT.VXMAX)   VX=0.5D0*(VXMAX+VXMIN)
8       VRX(K)=VX
9       CONTINUE
        VRX(K)=VX
C     ENDIF
90    CONTINUE
      RETURN
      END
C________________________________________________________________________
      SUBROUTINE OUTPUT
      IMPLICIT REAL*8 (A-H,O-Z)
C************************************************************************
C  <OUTPUT> CALLS <BIND> AND PRINTS DATA FROM THE CALCULATION.
C  FUNCTIONS ARE READ FROM UNIT 4 AND PRINTED.
C  CALLED BY <LIBMAIN>
C************************************************************************
      CHARACTER*60 NAME
      CHARACTER NLJ(50)*6
      CHARACTER*60 FISTRT,DENFIL,OUTFIL,WFFILE,TABFIL
      CHARACTER TEXCH(-3:5)*35
      CHARACTER TXTFEX(3)*60
      CHARACTER TXTLAT(0:1)*10
      COMMON /FILE/ FISTRT,DENFIL,OUTFIL,WFFILE,TABFIL
      COMMON /CHAR/   NAME
      COMMON /LIBGEN/ RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
      DATA(NLJ(I),I=1,50)/' 1S1/2',' 2S1/2',' 2P1/2',' 2P3/2',' 3S1/2','
     * 3P1/2',' 3P3/2',' 3D3/2',' 3D5/2',' 4S1/2',' 4P1/2',' 4P3/2',' 4D
     *3/2',' 4D5/2',' 4F5/2',' 4F7/2',' 5S1/2',' 5P1/2',' 5P3/2',' 5D3/2
     *',' 5D5/2',' 5F5/2',' 5F7/2',' 5G7/2',' 5G9/2',' 6S1/2',' 6P1/2','
     * 6P3/2',' 6D3/2',' 6D5/2',' 6F5/2',' 6F7/2',' 6G7/2',' 6G9/2',' 6H
     *9/2','6H11/2',' 7S1/2',' 7P1/2',' 7P3/2',' 7D3/2',' 7D5/2',' 7F5/2
     *',' 7F7/2',' 7G7/2',' 7G9/2',' 7H9/2','7H11/2','7I11/2','7I13/2','
     * 8S1/2'/
C
      DATA TEXCH(-3)/' FREE-ELECTRON E-DEPENDENT VX '/
      DATA TEXCH(-2)/' LIBERMAN EXCH.- TAIL CORRECTION'/
      DATA TEXCH(-1)/' SLATER RHO**1/3 '/
      DATA TEXCH( 0)/' GASPAR-KOHN-SHAM '/
C
      DATA TEXCH( 1)/' VON BARTH-HEDIN '/
      DATA TEXCH( 2)/' GUNNARSON-LUDQUIST'/
      DATA TEXCH( 3)/' JANAK-MORUZZI-WILLIAMS '/
      DATA TEXCH( 4)/' VOSKO-WILK-NUSAIR'/
C
      DATA (TXTFEX(I),I=1,3)/' SHAM-KOHN E-DEPNDT POTENTIAL USED'
     1,' SHAM-KOHN E-DEPNDT POTENTIAL USED IN COMP. BIND. ENERGIES'
     2,' BIND. ENERGIES COMPUTED VIA TOTAL ENERGY DIFFERENCES'/
C
         DATA (TXTLAT(I),I=0,1)/' NOT USED' ,' USED'/
         DATA P4/0.0795774715/
C
         REWIND( 4 )
C
         OPEN(UNIT=2,FILE=TABFIL,STATUS='UNKNOWN',FORM='FORMATTED')
C        """"""""""""""""""""""""""""""""""""""""""""""""""""""""""
         CALL BIND
C        =========
C
      WRITE (2,60)NAME
60    FORMAT(A60/)
        KLATTR=INT(XLATTR+.1)
      WRITE (2,13)TXTLAT(KLATTR),RNUC
      IF(KFEX.GE.1.AND.KFEX.LE.3)   WRITE (2,113)TXTFEX(KFEX)
113   FORMAT(1X,A60)
      KFEX = INT(FEX+.1)
      IF (KFEX.EQ.1)     WRITE (2,21)
      IF (KPOT.EQ.-2)     GOTO 1
      IF (KPOT.NE.-2)     GOTO 2
      IF (KFEX.LE.1)     WRITE (2,12)
      IF (KFEX.EQ.2)     WRITE (2,24)
      IF (KFEX.EQ.3)     WRITE (2,25)
      IFEX=KFEX+1
      GOTO 3
1     WRITE (2,26)R1
      IFEX=4
      WRITE (2,1025)
      WRITE (2,1026)
      GOTO 3
2     WRITE (2,27) TEXCH(KPOT)
      IFEX=4
C     WRITE (2,25)
      WRITE (2,1025)
      WRITE (2,1026)
3     DO 7 I=1,J
      NI=XN(I)*(XN(I)-2.0D0)+XL(I)+XJ(I)+1.501D0
      GOTO (4,4,5,6),IFEX
C4    WRITE (2,14)  NLJ(NI),XN(I),XL(I),XJ(I),XZ(I),2.*XE(I),PV(I)
4     WRITE (2,1014)NLJ(NI),XN(I),XL(I),XJ(I),XZ(I),2.*XE(I)
      GOTO 7
C5     WRITE (2,28)NLJ(NI),XN(I),XL(I),XJ(I),XZ(I),2.*XE(I),2.*BINDEN(I),PV(I)
5     WRITE (2,1028)NLJ(NI),XN(I),XL(I),XJ(I),XZ(I),2.*XE(I),
     *2.*BINDEN(I)
      GOTO 7
6     IF ((XZ(I).GE.1.0D0).AND.(XZ(I).LE.2.0D0*XJ(I)))
C    *WRITE (2,1029)NLJ(NI),XN(I),XL(I),XJ(I),XZ(I),2.*XE(I),
C    *2.*BINDEN(I)
C    *,PV(I)
     *WRITE (2,1029)NLJ(NI),XN(I),XL(I),XJ(I),XZ(I),2.*XE(I),
     *2.*BINDEN(I)
      IF (XZ(I).LT.1.0D0)
C    *WRITE (2,30)NLJ(NI),XN(I),XL(I),XJ(I),XZ(I),2.*XE(I),PV(I)
     *WRITE (2,1030)NLJ(NI),XN(I),XL(I),XJ(I),XZ(I),2.*XE(I)
      IF (XZ(I).GT.2.0D0*XJ(I))
C    *WRITE (2,29)NLJ(NI),XN(I),XL(I),XJ(I),XZ(I),2.*XE(I),2.*BINDEN(I)
     *WRITE (2,1029)NLJ(NI),XN(I),XL(I),XJ(I),XZ(I),2.*XE(I),
     *2.*BINDEN(I)
7     CONTINUE
      EKIN=SUMMA-EV3
      IF (RNUC.EQ.0.0D0)
     *EKIN=EKIN-EV4
      WRITE (2,15)ZN,Q,2.*SUMMA,2.*ET3,2.*EKIN,2.*EV4,2.*EV,2.*EE2
C      WRITE (2,60)NAME
C     WRITE (2,23)RN,N,H
C     WRITE (2,17)(RAD(K),K=1,N)
C     DO 9 K=1,N
C     S=1.0D0/RAD(K)
C     Y(K)=P4*RH(K)*S*S
C9     VRX(K)=(VR(K)-Z)*S
C     WRITE (2,11)NAME
C     WRITE (2,16)
C     WRITE (2,17)(Y(K),K=1,N)	!! print density
C     WRITE (2,11)NAME
C     WRITE (2,22)
C     WRITE (2,17)(VRX(K),K=1,N) !! print FULL potential
C________________________________________
C     WAVE FUNCTIONS PRINTING
C________________________________________
C        IF (NPRINT.EQ.1) THEN
C     DO 10 K=1,J
C     READ (4)(A(I),I=1,N)
C     READ (4)(B(I),I=1,N)
C     NI=XN(K)*(XN(K)-2.0D0)+XL(K)+XJ(K)+1.501D0
C     WRITE (2,20)NAME
C     WRITE (2,18)NLJ(NI)
C     WRITE (2,17)(A(I),I=1,N)
C     WRITE (2,20)NAME
C     WRITE (2,19)NLJ(NI)
C     WRITE (2,17)(B(I),I=1,N)
C10    CONTINUE
C        ENDIF
      CLOSE(2)
      RETURN
C
11    FORMAT(1H1,30X,A80,//)
12    FORMAT(4X,7HORBITAL,4X,1HN,4X,1HL,4X,1HJ,5X,9HELECTRONS,5X,10
     *HEIGENVALUE,5X,'PV',/)
13    FORMAT(' LATTER TAIL CORR. WAS',A10,
     *2X,' NUCLEAR RADIUS = ',E10.3,' A.U.')
14    FORMAT(5X,A6,3F5.1,F10.1,1PE20.7,17X,E15.7)
1014  FORMAT(5X,A6,3F5.1,F10.1,1PE20.7)
15    FORMAT(/20X,15HNUCLEAR CHARGE=,F12.6/8X,'INTEGRAL OF CHARGE DENSIT
     *Y='
     *,F12.6/5X,30HSUM OF THE ENERGY EIGENVALUES=,F12.4/22X,         13H
     *TOTAL ENERGY=,F12.4/20X,15HKINETIC ENERGY=,F12.4/14X,21HE-N POTENT
     *IAL ENERGY=,F12.4/14X,21HE-E POTENTIAL ENERGY=,F12.4/19X,16HEXCHAN
     *GE ENERGY=,F12.4)
16    FORMAT(53X,'RHO(R)'/)
17    FORMAT(1H ,8E14.7)
18    FORMAT(1H ,20X,'R TIMES MAJOR COMPONENT OF THE ',A6,' ORBITAL')
19    FORMAT(1H ,20X,'R TIMES MINOR COMPONENT OF THE ',A6,' ORBITAL')
20    FORMAT(1H1,10A80/)
21    FORMAT(' FREE ELECTRON HARTREE-FOCK EXCHANGE ')
22    FORMAT(47X,'POTENTIAL FUNCTION'/)
23    FORMAT(12X,41H TABLE OF RADII. RN=RMAX*EXP((N-NMAX)*H).,'RMAX=',F8
     *.4,' NMAX=',I5,' H= ',F10.8/)
24    FORMAT(5X,7HORBITAL,4X,1HN,4X,1HL,4X,1HJ,5X,9HELECTRONS,5X,10
     *HEIGENVALUE,5X,2HPV,13X,18HH-F BINDING ENERGY,/)
25    FORMAT(4X,7HORBITAL,4X,1HN,4X,1HL,4X,1HJ,5X,9HELECTRONS,5X,10
     *HEIGENVALUE,6X,11HE(N)-E(N-1),6X,11HE(N)-E(N+1))
1025  FORMAT(5X,7HORBITAL,4X,1HN,4X,1HL,4X,1HJ,5X,9HELECTRONS,5X,10
     *HEIGENVALUE,6X,11HE(N)-E(N-1))
1026   FORMAT(4X,7H       ,4X,1H ,4X,1H ,4X,1H ,5X,9H         ,5X,10
     *H   (RY)   ,6X,11H   (RY)     /)
26    FORMAT(10X,' LIBERMAN POTENTIAL USED. R1 = ',F8.5)
27    FORMAT(' EXCHANGE AND CORRELATION :: ',A35/)
28    FORMAT(5X,A6,2X,3F5.1,F10.1,1PE19.7,E15.7,E15.7)
1028  FORMAT(5X,A6,2X,3F5.1,F10.1,1PE19.7,E17.7)
29    FORMAT(5X,A6,2X,3F5.1,F10.1,1PE19.7,2E17.7)
1029  FORMAT(5X,A6,2X,3F5.1,F10.1,1PE19.7,E17.7)
30    FORMAT(5X,A6,2X,3F5.1,F10.1,1PE19.7,17X,E17.7)
1030  FORMAT(5X,A6,2X,3F5.1,F10.1,1PE19.7,E17.7)
      END
C_______________________________________________________________________
      SUBROUTINE OUTDAT
      IMPLICIT REAL*8 (A-H,O-Z)
C-----------------------------------------------------------------------
       CHARACTER*60 NAME
      CHARACTER*60 FISTRT,DENFIL,OUTFIL,WFFILE,TABFIL
      COMMON /FILE/ FISTRT,DENFIL,OUTFIL,WFFILE,TABFIL
      COMMON /CHAR/   NAME
      COMMON /LIBGEN/ RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
      COMMON /CORE/JCORE
	DIMENSION NNIZ(35)
C
	PARAMETER (PI=3.142592653589793, PI4=4.*PI)
        DATA P4/0.0795774715/
C
        REWIND( 4 )
C
	DO 200 K = 1,N
	DENS(K)  = 0.
200	RHNLJ(K) = 0.
C      DO 9 K=1,N
C      S=1.0D0/RAD(K)
C      Y(K)=P4*RH(K)*S*S	!! TOTAL DENSITY
C9     VRX(K)=(VR(K)-Z)*S	!! POTENTIAL
C   _____________________________________________________________
C   DENS(K) = FULL CHARGE DENSITY, RHNLJ(K) = CORE CHARGE DENSITY
C   """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
      DO 10 I=1,JCORE
      READ (4)(A(L),L=1,N)
      READ (4)(B(L),L=1,N)
C   ====================================================================
C   DENS ---> RO(1:N),          RHNLJ ---> ROC(1:N)
C             TOTAL DENSITY                CORE DENSITY
C   ====================================================================
	DO 210 K=1,N
	DENS (K) = DENS(K) +  XZ(I)*( A(K)**2 + B(K)**2 )/(PI4*RAD(K)**2)
210	RHNLJ(K) = RHNLJ(K) + XZ(I)*( A(K)**2 + B(K)**2 )/(PI4*RAD(K)**2)
10    CONTINUE
      DO 11 I=JCORE+1,J
      READ (4)(A(L),L=1,N)
      READ (4)(B(L),L=1,N)
	DO 211 K=1,N
	DENS (K) = DENS(K) +  XZ(I)*( A(K)**2 + B(K)**2 )/(PI4*RAD(K)**2)
211	CONTINUE
11    CONTINUE
C
C      OUTPUT DATA IN USUAL WAY (FOR LMTO SCF-FILE)
C      ============================================
        OPEN(2,FILE=OUTFIL,STATUS='UNKNOWN',FORM='FORMATTED')
C	"""""""""""""""""""""""""""""""""""""""""""""""""""""	
       WRITE (2,60)NAME
60	FORMAT(A60)
	WRITE(2,*) JCORE,J,N
c  !! CORE ORB.,TOT.ORB.,MESH DIMEN.
	WRITE(2,101)(DENS(K),K=1,N)	
c  !! RO
101	FORMAT(3X,2(1X,G21.14))
	WRITE(2,101)(RHNLJ(K),K=1,N)	
C  !! ROC
C       WRITE(2,*)(RAD(K),K=1,N)	!! RADIAL MESH
C       ---------------------------
        WRITE (2,*)(XZ(L),L=1,J)	
C   !! OCCCUPTION NUMBERS
        WRITE (2,*)(2.*XE(L),L=1,J)	
C   !! LEVELS (IN RY UNITS !!!)
	DO 220 L = 1,J
220	NNIZ(L) = INT(  100*XN(L)+10*XL(L)+2*XJ(L) +.1  )
	WRITE (2,*)(NNIZ(L),L=1,J)	
C   !! CORE STRUCTURE (MASKED)
	CLOSE(2)
C       ----------------------------------------------
      RETURN
      END
      SUBROUTINE LIDEQ(DELL)
      IMPLICIT REAL*8 (A-H,O-Z)
C----------------------------------------------------------------------
C  CONTROL SUBROUTINE FOR THE INTEGRATION OF THE DIFFERENTIAL EQUATIONS.
C  FINDS EIGENVALUES. NORMALIZES ORBITAL FUNCTIONS.
C  CALLED BY <LIBDIR> AND <BIND>.
C
C  A.M.BRATKOVSKY (1989) REVISION FOR MS DOS FORTRAN
C______________________________________________________________________
C     CHANNEL INFUN IS USED FOR OUTPUT DIAGNOSIS INFORMATION
C______________________________________________________________________
       CHARACTER*60 NAME
      COMMON /CHAR/NAME
      COMMON /LIBGEN/RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
       CHARACTER*60 INFFILE
       COMMON /LIBINF/INF,INFUN,INFFILE
C
      DATA C/137.0360411D0/
C
      DELK=0.01
      EMIN=-(ZN/FN)**2
      EMAX=-0.00001
      IF (BCOND.EQ.1.0D0)     EMAX=MAX(1.0D0 , 10.D0/RN**2)
      IF (E.GT.EMAX.OR.E.LT.EMIN)
     *E=0.5D0*(EMAX+EMIN)
      S=2.0D0*(FJ-FL)
      CS=C*S
      G=DSQRT((FJ+0.5D0)**2-(Z/CS)**2)
      H3=H/3.0D0
1     CALL START1
      CALL DIFF1(KI,NUMQ)
C      WRITE(INFUN,2000)FN,FL,FJ,E,KI
C2000  FORMAT(' N,L,J,E ',4(1X,G10.5),' KI= ',I4)
C  .....................................................
C  NUMQ = NUMBER OF NODES + L + 1. NUMQ SHOULD EQUAL FN.
C  """""""""""""""""""""""""""""""""""""""""""""""""""""
      IF ( INT( FN + 0.1 ) - NUMQ)    2 , 4 , 13
C          ****************************
C          *    TOO MANY NODES.	      *
C          ****************************
2     IF (E.LT.EMAX) EMAX=E
      E=0.5D0*(E+EMIN)
      DL1=ABS(EMAX-EMIN)/(ABS(E)+1.0D0)
      IF (DL1.GE.DELK)
     *GOTO 1
      WRITE (INFUN,15)NUMQ,FN,FL,FJ,2.*EMIN,2.*E,2.*EMAX
15    FORMAT(10X,'TOO MANY NODES'/
     * 'NZ+L+1   N    L    J          EMIN         E             EMAX'/
     * ,I2,7X,F2.0,3X,F2.0,3X,F3.1,2X,3(1X,E13.3))
      EMIN=1.2D0*EMIN
      GOTO 1
C       *********************************
C       *  CORRECT NUMBER OF NODES      *
C       *********************************
4     AKI=A(KI)
      BKI=B(KI)
                CALL START2(KI,KJ)
                CALL DIFF2(KI,KJ)
      AIK=A(KI)
      BIK=B(KI)
      RA=AKI/AIK
      RB=BKI/BIK
      DO 5 K=KI,KJ
      A(K)=A(K)*RA
5     B(K)=B(K)*RA
      DG=DEXP(H*G)
      RG=RN**G/DG**N
      DO 6 K=1,KJ
      RG=RG*DG
      A(K)=A(K)*RG
6     B(K)=B(K)*RG
      IF (KJ.EQ.N) GOTO 8
      RJ=RAD(KJ)
      DO 7 K=KJ,N
      R=RAD(K)
      W=DEXP(-DSQRT(-2.0D0*E)*(R-RJ)  )
      A(K)=A(KJ)*W
7     B(K)=B(KJ)*W
8     CONTINUE
      DO 9 K=1,N
      R=RAD(K)
      AK=A(K)
      BK=B(K)
      IF(ABS(AK).LE.1.E-34)AK=0.
      IF(ABS(BK).LE.1.E-34)BK=0.
      Y(K)=(AK*AK+BK*BK)*R
9     CONTINUE
      W=ADLINT(Y,N,H)
      W=W+Y(1)/(G+G+1.0D0)
        EINI=E
      DE=CS*A(KI)*B(KI)*(1.0D0-RB/RA)/W
      DL1=DABS(EMAX-EMIN)/(DABS(E)+1.0D0)
      DL=DABS(DE)/(DABS(E) + 1.D-12)
      IF ((DL.GT.DELK).AND.(DL1.LT.DELK))
     *GOTO 12
      IF (DL1.LT.DELL)
     *GOTO 12
      IF (DE.GT.0.0D0)
     *EMIN=E
      IF (DE.LT.0.0D0)
     *EMAX=E
      E=E+DE
      IF (DL.LT.DELL)
     *GOTO 10
      IF (E.GT.EMAX)
     *E=0.5D0*(E-DE+EMAX)
      IF (E.LT.EMIN)
     *E=0.5D0*(E-DE+EMIN)
         EOUT =E
      GOTO 1
10    X=1.0D0/DSQRT(W)
      IF(W.LE.1.E-10)THEN
        RENORM=1.E10
      ELSEIF(W.GE.1.E10)THEN
        RENORM=1.E-10
      ELSE
        RENORM=1.
      ENDIF
      DO 11 K=1,N
      AK=A(K)
      BK=B(K)
      IF(ABS(AK).LE.1.E-34)AK=0.
      IF(ABS(BK).LE.1.E-34)BK=0.
      A(K)=(RENORM*AK)*(X/RENORM)
11    B(K)=(RENORM*BK)*(X/RENORM)
      RETURN
12    WRITE (INFUN,16)FN,FL,FJ,2.*EMIN,2.*E,2.*EMAX,2.*DE
16    FORMAT('DE TOO LARGE:'/
     * 'N    L    J            EMIN         E            EMAX       DE'/
     * ,F2.0,3X,F2.0,3X,F3.1,2X,4(1X,E13.3))
      GOTO 10
C           **************************
C           *    TOO FEW NODES.      *
C           **************************
13    IF (E.GT.EMIN)     EMIN=E
C
      E=0.5D0*(EMIN+EMAX)
C      DL1=DABS(EMAX-EMIN)/(DABS(E)+1.0D0)
C      IF (DL1.LT.DELK)     GOTO 14
C
      DL=DABS(EMAX-EMIN)/(DABS(E)+1.0D-12)
      IF (DL.LT.DELK)     THEN
      WRITE (INFUN,17)DELK,NUMQ,FN,FL,FJ,2.*EMIN,2.*E,2.*EMAX
17    FORMAT('TOO FEW  NODES,WARNING: |EMAX-EMIN|/|E|<',F5.3/
     * 'NZ+L+1   N    L    J           EMIN         E             EMAX'/
     * ,I2,7X,F2.0,3X,F2.0,3X,F3.1,2X,3(1X,E13.3))
	ENDIF
C
      GOTO 1
C
C14    WRITE (INFUN,17)NUMQ,FN,FL,FJ,2.*EMIN,2.*E,2.*EMAX
C17    FORMAT('TOO FEW  NODES:'/
C     * 'NZ+L+1,  N ,  L ,  J ,         EMIN,       E,          EMAX'/
C     * ,I2,7X,F2.0,3X,F2.0,3X,F3.1,2X,3(1X,E13.3))
C	IF (BCOND.EQ.1.0D0)     STOP 'BCOND=1: MISMATCH IN <LIDEQ>'
C	BCOND=1.0D0
C       EMAX=DMAX1(1.0D0,10.0D0/RN**2)
C       E=0.5D0*(E+EMAX)
C      GOTO 1
C
      END
      SUBROUTINE START1
      IMPLICIT REAL*8 (A-H,O-Z)
C  -----------------------------------------------
C  STARTS OUTWARD INTEGRATION WITH A POWER SERIES.
C  CALLED BY <LIDEQ>.
C  -----------------------------------------------
       CHARACTER*60 NAME
C
      COMMON /CHAR/NAME
      COMMON /LIBGEN/RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
C
      DATA C/137.03602D0/
C
      H3=H/3.0D0
      S=2.0D0*(FJ-FL)
      CS=C*S
      G=DSQRT((FJ+0.5D0)**2-(Z/CS)**2)
      GP=G+S*(FJ+0.5D0)
      GM=G-S*(FJ+0.5D0)
      P21=(E-V0)/CS
      P12=-P21-2.0D0*CS
      Q11=-GM
      Q21=Z/CS
      Q12=-Q21
      Q22=-GP
      A0(1)=DSQRT(+S*GP)
      B0(1)=DSQRT(-S*GM)
      FI=0.0D0
      DO 1 I=2,5
      FI=FI+1.0D0
      W1=P12*B0(I-1)/FI
      W2=P21*A0(I-1)/FI
      A0(I)=W1+(Q11*W1+Q12*W2)/(FI+2.0D0*G)
1     B0(I)=W2+(Q21*W1+Q22*W2)/(FI+2.0D0*G)
      DO 2 K=1,5
      R=RAD(K)
      A(K)=A0(1)+R*(A0(2)+R*(A0(3)+R*(A0(4)+R*A0(5))))
      B(K)=B0(1)+R*(B0(2)+R*(B0(3)+R*(B0(4)+R*B0(5))))
      DA(K)=H3*(Q11*A(K)+(R*P12+Q12)*B(K))
2     DB(K)=H3*(Q22*B(K)+(R*P21+Q21)*A(K))
      RETURN
      END
      SUBROUTINE DIFF1(KI,NUMQ)
      IMPLICIT REAL*8 (A-H,O-Z)
C  ------------------------------------------------------------------
C  INTEGRATES OUTWARD TO CLASSICAL TURNING POINT. COUNTS NODES IN THE
C  MAJOR COMPONENT OF THE RADIAL WAVE FUNCTION.
C  CALLED BY <LIDEQ>.
C  ------------------------------------------------------------------
       CHARACTER*60 NAME
C
      COMMON /CHAR/NAME
      COMMON /LIBGEN/RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
      DATA C/137.03602D0/
C
      H3=H/3.0D0
      S=2.0D0*(FJ-FL)
      CS=C*S
      G=DSQRT((FJ+0.5D0)**2-(Z/CS)**2)
      Q11=-G+S*(FJ+0.5D0)
      Q22=-G-S*(FJ+0.5D0)
      DA(1)=DA(2)
      DB(1)=DB(2)
      DA(2)=DA(3)
      DB(2)=DB(3)
      DA(3)=DA(4)
      DB(3)=DB(4)
      NUMQ=INT(1.1D0+FL)
      M=N-10
      DO 1 K=11,M
      KM=N-K
      R=RAD(KM)
      IF (E*R+Z-VR(KM)-0.5*FL*(FL+1.0D0)/R.GT.0.0D0)
     *GOTO 2
1     CONTINUE
2     KI=KM+1
      DO 3 K=5,KI
      R=RAD(K)
      RP21=(E*R-VR(K)-VRX(K)+Z)/CS
      RP12=-RP21-2.0D0*CS*R
      A(K)=A(K-4)+8.0D0*(DA(3)-0.5D0*DA(2)+DA(1))
      B(K)=B(K-4)+8.0D0*(DB(3)-0.5D0*DB(2)+DB(1))
      DA(4)=H3*(Q11*A(K)+RP12*B(K))
      DB(4)=H3*(Q22*B(K)+RP21*A(K))
      A(K)=A(K-1)+1.125D0*DA(4)+2.375D0*DA(3)-0.625D0*DA(2)+0.125D0*DA(1
     *)
      B(K)=B(K-1)+1.125D0*DB(4)+2.375D0*DB(3)-0.625D0*DB(2)+0.125D0*DB(1
     *)
      DA(1)=DA(2)
      DB(1)=DB(2)
      DA(2)=DA(3)
      DB(2)=DB(3)
      DA(3)=H3*(Q11*A(K)+RP12*B(K))
      DB(3)=H3*(Q22*B(K)+RP21*A(K))
3     NUMQ=NUMQ +
     P      INT(0.1D0 + ABS(SIGN(1.D0,A(K))-SIGN(1.D0,A(K-1)))/2.D0)
      RETURN
      END
      SUBROUTINE START2(KI,KJ)
      IMPLICIT REAL*8 (A-H,O-Z)
C  ---------------------------------------------------------------
C  STARTS INWARD INTEGRATION. OUTER BOUNDARY CONDITION IS SET HERE.
C  CALLED BY <LIDEQ>.
C  ---------------------------------------------------------------
       CHARACTER*60 NAME

      COMMON /CHAR/NAME
      COMMON /LIBGEN/RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
       CHARACTER*60 INFFILE
	COMMON /LIBINF/INF,INFUN,INFFILE
C
      DATA C/137.03602D0/
C
      H3=-H/3.0D0
      S=2.0D0*(FJ-FL)
      CS=C*S
      G=DSQRT((FJ+0.5D0)**2-(Z/CS)**2)
      Q22=-G-S*(FJ+0.5D0)
      Q11=-G+S*(FJ+0.5D0)
      DO 1 K=KI,N
      R=RAD(K)
      IF ((E*R-VR(K)+Z)*R+EPS)2,1,1
1     CONTINUE
2     IF(K.LE.N)THEN
      KJ=K
      ELSE
      KJ=N
      ENDIF
      IF (INT(BCOND+.1).EQ.0) THEN
C  *******************************************
C       ISOLATED ATOM BOUNDARY CONDITIONS.   *
C  *******************************************
      RZ=(Z-VR(KJ))/R
      RL=(FL+0.5D0)/R
      RK=-S*(FJ+0.5D0)/R
      P=-2.0D0*(E+RZ)+RL*RL
      IF (P.LT.0.0D0) THEN
      WRITE (INFUN,8)RAD(KJ)
8     FORMAT('THE TURNING POINT ',F6.3,' IS ABOVE "RN".'/
     * 'A LARGER VALUE OF "RN" MAYBE NEEDED.')
      ENDIF
      P=DSQRT(ABS(P))
      APA=-P+0.5D0*(RZ-RL*RL)/(R*P**2)
      A(KJ)=1.0D0
      B(KJ)=CS*(APA+RK)/(-2.0D0*C*C-E-RZ)
C     GOTO 4
        ELSE
C____________________________________________
C  WIGNER-SEITZ BOUNDARY CONDITIONS.
C____________________________________________
      B(KJ)=DMOD(FL,2.0D0)
      A(KJ)=1.0D0-B(KJ)
        ENDIF
C
C4	CONTINUE
      DO 5 L=1,4
      K=KJ-L
      A(K)=A(KJ)
5     B(K)=B(KJ)
      DO 7 I=1,4
      K=KJ+1
      DO 6 L=1,5
      K=K-1
      R=RAD(K)
      RP21=(E*R-VR(K)-VRX(K)+Z)/CS
      RP12=-RP21-2.0D0*CS*R
      DA(L)=H3*(Q11*A(K)+RP12*B(K))
6     DB(L)=H3*(Q22*B(K)+RP21*A(K))
      A(KJ-1)=A(KJ)+(251.0D0*DA(1)+646.0D0*DA(2)-264.0D0*DA(3)+106.0D0*D
     *A(4)-19.0D0*DA(5))/240.0D0
      B(KJ-1)=B(KJ)+(251.0D0*DB(1)+646.0D0*DB(2)-264.0D0*DB(3)+106.0D0*D
     *B(4)-19.0D0*DB(5))/240.0D0
      A(KJ-2)=A(KJ)+(116.0D0*DA(1)+496.0D0*DA(2)+96.0D0*DA(3)+16.0D0*DA(
     *4)-4.0D0*DA(5))/120.0D0
      B(KJ-2)=B(KJ)+(116.0D0*DB(1)+496.0D0*DB(2)+96.0D0*DB(3)+16.0D0*DB(
     *4)-4.0D0*DB(5))/120.0D0
      A(KJ-3)=A(KJ)+(81.0D0*DA(1)+306.0D0*DA(2)+216.0D0*DA(3)+126.0D0*DA
     *(4)-9.0D0*DA(5))/80.0D0
      B(KJ-3)=B(KJ)+(81.0D0*DB(1)+306.0D0*DB(2)+216.0D0*DB(3)+126.0D0*DB
     *(4)-9.0D0*DB(5))/80.0D0
      A(KJ-4)=A(KJ)+(56.0D0*DA(1)+256.0D0*DA(2)+96.0D0*DA(3)+256.0D0*DA(
     *4)+56.0D0*DA(5))/60.0D0
7     B(KJ-4)=B(KJ)+(56.0D0*DB(1)+256.0D0*DB(2)+96.0D0*DB(3)+256.0D0*DB(
     *4)+56.0D0*DB(5))/60.0D0
      RETURN
C
      END
      SUBROUTINE DIFF2(KI,KJ)
      IMPLICIT REAL*8 (A-H,O-Z)
C  -------------------------------------------------
C  INTEGRATES INWARD TO THE CLASSICAL TURNING POINT.
C  CALLED BY <LIDEQ>.
C  -------------------------------------------------
      CHARACTER*60 NAME
C
      COMMON /CHAR/NAME
      COMMON /LIBGEN/RN,H,H1,Z,ZN,XION,PHI,EPS,DEL,DELRVR,TIME
     *,XALPHA,XLATTR,FEX,RNUC,XN(35),XL(35),XJ(35),XE(35),XZ(35
     *),BCOND,RH(421),FN,FL,FJ,E,VR(421),Q,EV,ED,EV3,ER,EV4,EZ,EE2,EY,V0
     *,ET3,SUMMA,PVT,CONVRG,PV(35),A(421),B(421),RHNLJ(421),DENS(421),Y(
     *421),BINDEN(35),DA(5),DB(5),A0(5),B0(5),VRX(421),XKOOP,R1,RAD(421)
      COMMON /LIB2/ NT,N,J,NC1,NDEBUG,NPRINT,NREAD,KPOT
      DATA C/137.03596315/
C
      H3=-H/3.0D0
      S=2.0D0*(FJ-FL)
      CS=C*S
      G=DSQRT((FJ+0.5D0)**2-(Z/CS)**2)
      Q11=-G+S*(FJ+0.5D0)
      Q22=-G-S*(FJ+0.5D0)
      K=KJ-3
      DA(1)=DA(2)
      DB(1)=DB(2)
      DA(2)=DA(3)
      DB(2)=DB(3)
      DA(3)=DA(4)
      DB(3)=DB(4)
1     K=K-1
      R=RAD(K)
      RP21=(E*R-VR(K)-VRX(K)+Z)/CS
      RP12=-RP21-2.0D0*CS*R
      A(K)=A(K+4)+8.0D0*(DA(3)-0.5D0*DA(2)+DA(1))
      B(K)=B(K+4)+8.0D0*(DB(3)-0.5D0*DB(2)+DB(1))
C
      DA(4)=H3*(Q11*A(K)+RP12*B(K))
      DB(4)=H3*(Q22*B(K)+RP21*A(K))
      A(K)=A(K+1)+1.125D0*DA(4)+2.375D0*DA(3)-0.625D0*DA(2)+0.125D0*DA(1
     *)
      B(K)=B(K+1)+1.125D0*DB(4)+2.375D0*DB(3)-0.625D0*DB(2)+0.125D0*DB(1
     *)
      DA(1)=DA(2)
      DB(1)=DB(2)
      DA(2)=DA(3)
      DB(2)=DB(3)
      DA(3)=H3*(Q11*A(K)+RP12*B(K))
      DB(3)=H3*(Q22*B(K)+RP21*A(K))
      IF (K.GT.KI)
     *GOTO 1
      RETURN
      END
C***********************************************************************
      FUNCTION ADLINT (Y,N,H)
      IMPLICIT REAL*8 (A-H,O-Z)
C  -----------------------------------------------------
C  EULER-MACLAURIN INTEGRATION FORMULA. N MUST EXCEED 10.
C  CALLED BY <POT>, <DIFFER>, AND <BIND>.
C  -----------------------------------------------------
      DIMENSION Y(421)
      DATA CA,CB,CC,CD,CE/0.329861111D0,1.320833333D0,0.766666667D0,1.10
     *1388889D0,0.981250000D0/
C
      SUM=CA*(Y(1)+Y(N))+CB*(Y(2)+Y(N-1))+CC*(Y(3)+Y(N-2))+CD*(Y(4)+Y(N-
     *3))+CE*(Y(5)+Y(N-4))
      M=N-5
      DO 1 K=6,M
1     SUM=SUM+Y(K)
      ADLINT=SUM*H
      RETURN
      END
      FUNCTION VXC(RUP,RDN,I,K)
C *****************************************	
C 	VXC-EXCH.-CORREL. POTENTIAL,
C 	VX-EXCH.POT.,VC-CORREL.POT.,
C 	RUP,RDN-SP,UP AND SP.DOWN DENS.
C 	I=1,2,3,4-BY VBARTH-H.,GUNN.-L.,JAN.-W.-M.,VOSK.-WILL. RESP.
C 	K=1,2-SPIN UP,SPIN DOWN VXC
C********************************************
      implicit real*8 (A-H,O-Z)
      PARAMETER(PI=3.141592653589793)
      PARAMETER(ALF=0.521062)
      PARAMETER(OTH=1./3.)
      PARAMETER(FTH=4./3.)
      PARAMETER(AA=.519842)
C
      DIMENSION CCP(3),CCF(3),RP(3),RF(3)
      DATA CCP/0.0504,0.0666,0.045/,CCF/0.0254,0.0406,0.0357/
     1       RP/30.,11.4,21./, RF/75.,15.9,26.5/
      DATA AP,XP0,BP,CP,QP,CP1,CP2,CP3/0.0621814,-0.10498,
     %     3.72744,12.9352,6.1519908,1.2117833,1.1435257,
     %    -0.031167608/
      DATA AF,XF0,BF,CF,QF,CF1,CF2,CF3/0.0310907,-0.32500,
     %     7.060428,18.0578,4.7309269,2.9847935,2.7100059,
     %    -0.1446006/
C      **********************************
      ECX(X)=-((1.+X**3)*LOG(1.+1./X)+X/2.-X*X-1./3.)
      DECX(X)=-(3.*X*X*LOG(1.+1./X)-(1.+X**3)/
     1                 (X*X+X)+1./2.-2.*X)
      G1(Y)=(1.-Y)**(4./3.)
      F(Y)=((1.+Y)**(4./3.)+G1(Y)-2.)/(2.*(2.**(1./3.)-1.))
      RHO=RUP+RDN
      IF(RHO.LE.1.E-9)THEN
      VXC=0.0
      RETURN
      ENDIF
      IF (I.EQ.4)THEN
      RHO1=RUP
      RHO2=RDN
      RS1=(RHO/3.)**OTH
      RS=1./RS1
      X=SQRT(RS)
      XPX=X*X+BP*X+CP
      S=(RHO2-RHO1)/RHO
      SP=1.+S
      SM=1.-S
      S4=S**4-1.
      FS=(SP**FTH+SM**FTH-2.)/AA
      BETA=1./(2.74208+3.182*X+0.09873*X*X+0.18268*X**3)
      DFS=FTH*(SP**OTH-SM**OTH)/AA
      DBETA=-(0.27402*X+0.09873+1.591/X)*BETA**2
      ATNP=ATAN(QP/(2.*X+BP))
      ECP=AP*(LOG(X*X/XPX)+CP1*ATNP-CP3*(LOG((X-XP0)**2/XPX)
     %+CP2*ATNP))
      XFX=X*X+BF*X+CF
      ATNF=ATAN(QF/(2.*X+BF))
      ECF=AF*(LOG(X*X/XFX)+CF1*ATNF-CF3*(LOG((X-XF0)**2/XFX)
     %+CF2*ATNF))
      EC=ECP+FS*(ECF-ECP)*(1.+S4*BETA)
      TP1=(X*X+BP*X)/XPX
      TF1=(X*X+BF*X)/XFX
      UCP=ECP-AP/3.*(1.-TP1-CP3*(X/(X-XP0)-TP1-XP0*X/XPX))
      UCF=ECF-AF/3.*(1.-TF1-CF3*(X/(X-XF0)-TF1-XF0*X/XFX))
      UC0=UCP+(UCF-UCP)*FS
      UC20=UC0+(ECF-ECP)*SM*DFS
      UC10=UC0-(ECF-ECP)*SP*DFS
      DUC=(UCF-UCP)*BETA*S4*FS+(ECF-ECP)*(-RS/3.)*DBETA*S4*FS
      DUC2=DUC+(ECF-ECP)*BETA*SM*(4.*S**3*FS+S4*DFS)
      DUC1=DUC-(ECF-ECP)*BETA*SP*(4.*S**3*FS+S4*DFS)
      UC1=UC10+DUC1
      UC2=UC20+DUC2
      EPX=-0.91633059/RS*(1.+FTH*FS/5.1297628)
      AMYX2=-1.22177412/RS*SP**OTH
      AMYX1=-1.22177412/RS*SM**OTH
      EXC=2.D0*(EC+EPX)
      IF (K.EQ.1)THEN
      VXC=2.*(UC1+AMYX1)
      ELSE
        VXC=2.*(UC2+AMYX2)
      ENDIF
      ELSE
      RS=(3./(4.*PI*(RUP+RDN)))**(1./3.)
      Y=ABS((RUP-RDN))/(RUP+RDN)
      G2=(1.-Y)**(1./3.)
      XP=RS/RP(I)
      XF=RS/RF(I)
      O=(-1)**K
      EC=CCP(I)*ECX(XP)+(CCF(I)*ECX(XF)-CCP(I)*ECX(XP))*F(Y)
      DEC=(CCF(I)*ECX(XF)-CCP(I)*ECX(XP))*((1.+Y)**(1./3.)-G2)*
     1                          (4./(6.*(2.**(1./3.)-1.)))
      VX=(-2./(PI*ALF*RS))*((1.-O*Y)**(1./3.))
      VC=EC-(RS/3.)*(CCP(I)/RP(I)*DECX(XP)+
     1 (CCF(I)/RF(I)*DECX(XF)-CCP(I)/RP(I)*
     2  DECX(XP))*F(Y))-O*(1.+O*Y)*DEC
      VXC=VX+VC
      ENDIF
      RETURN
      END
      FUNCTION EXC(ROUP,RODN,I)
C************************************
C	EXC-EXCH.-CORREL. ENERGY,
C	EXH-EXCHANGE EN.,EC-CORREL. EN.,
C	ROUP,RODN-SPIN UP AND SP DOWN DENSITY
C	I=1-BY VBARTH-H.,
C	 =2-BY GUNNARS.-L.,
C	 =3-BY JANAK ET.AL.,
C	 =4-BY VOSKO ET.AL.
C***************************************
      implicit real*8 (A-H,O-Z)
      PARAMETER(PI=3.141592653589793)
      PARAMETER(ALF=0.521062)
      PARAMETER(OTH=1./3.)
      PARAMETER(FTH=4./3.)
      PARAMETER(AA=.519842)
C
      DIMENSION CCP(3),CCF(3),RP(3),RF(3)
      DATA CCP/0.0504,0.0666,0.045/,CCF/0.0254,0.0406,0.0357/
     1       RP/30.,11.4,21./, RF/75.,15.9,26.5/
      DATA AP,XP0,BP,CP,QP,CP1,CP2,CP3/0.0621814,-0.10498,
     %     3.72744,12.9352,6.1519908,1.2117833,1.1435257,
     %    -0.031167608/
      DATA AF,XF0,BF,CF,QF,CF1,CF2,CF3/0.0310907,-0.32500,
     %     7.060428,18.0578,4.7309269,2.9847935,2.7100059,
     %    -0.1446006/
C      **********************************
	RHO=ROUP+RODN
	IF(RHO.LE.1.E-09)THEN
	EXC=0.0
	RETURN
	ENDIF
	IF (I.EQ.4)THEN
	RHO1=ROUP
	RHO2=RODN
      RS1=(RHO/3.)**OTH
      RS=1./RS1
      X=SQRT(RS)
          XPX=X*X+BP*X+CP
      S=(RHO2-RHO1)/RHO
      SP=1.+S
      SM=1.-S
      S4=S**4-1.
      FS=(SP**FTH+SM**FTH-2.)/AA
      BETA=1./(2.74208+3.182*X+0.09873*X*X+0.18268*X**3)
      ATNP=ATAN(QP/(2.*X+BP))
      ECP=AP*(LOG(X*X/XPX)+CP1*ATNP-CP3*(LOG((X-XP0)**2/XPX)
     %+CP2*ATNP))
      XFX=X*X+BF*X+CF
      ATNF=ATAN(QF/(2.*X+BF))
      ECF=AF*(LOG(X*X/XFX)+CF1*ATNF-CF3*(LOG((X-XF0)**2/XFX)
     %+CF2*ATNF))
      EC=ECP+FS*(ECF-ECP)*(1.+S4*BETA)
      EPX=-0.91633059/RS*(1.+FTH*FS/5.1297628)
      EXC=2.D0*(EC+EPX)
	ELSE
	RS=(3./(4.*PI*(ROUP+RODN)))**(1./3.)
	XP=RS/RP(I)
	XF=RS/RF(I)
	Y=(ROUP-RODN)/(ROUP+RODN)
	ECXP=-((1.+XP**3)*LOG(1.+1./XP)+XP/2.-XP*XP-1./3.)
	ECXF=-((1.+XF**3)*LOG(1.+1./XF)+XF/2.-XF*XF-1./3.)
	F=((1.+Y)**(4./3.)+(1.-Y)**(4./3.)-2.)/(2*(2**(1./3.)-1))
	EXHP=-3./(2.*PI*ALF*RS)
	EXH=EXHP+EXHP*(2.**(1./3.)-1.)*F
	EC=CCP(I)*ECXP+(CCF(I)*ECXF-CCP(I)*ECXP)*F
	EXC=EXH+EC
	END IF
C
	RETURN
	END
   
     
